from setuptools import setup

setup( 
    name='Knifey',
    version='0.1.0',
    author='gabefgonc',
    author_email='gabefgonc@gmail.com',
    packages=['knifey'],
    url='http://pypi.python.org/pypi/knifey/',
    download_url='https://github.com/gabefgonc/knifey/releases/download/v0.1.0/knifey_v01.tar.gz',
    description='A module to make writing day-to-day scripts easier',
    long_description=open('README.txt').read()
)
